@@ -32,12 +32,14 @@ sub new {
 
 sub scan{
       my $self = shift;
+      my %params = @_; 
 
-      my %params;
       my $tables = $self->scan_tables() || die "failed to scan tables";
       my $pkeys = $self->scan_pkeys(); # || die "failed to scan primary keys";
 
       foreach my $table (@{$tables}){
+            print "Scanning $table\n" if $params{pretty};
+            
        	    my $fields = $self->scan_fields($table) or return $self->_error( "failed to describe table" );
             my $pkey = $pkeys ? $pkeys->{$table} : $self->scan_pkeys( $table );
 
@@ -56,9 +58,10 @@ sub scan_pkeys {
       my $dbh = $self->{scan_instance}->connect('dbh') || die "failed to connect to scanned db";
 
       my $sth;
+      local $dbh->{PrintError} = 0;
       eval { $sth= $dbh->primary_key_info(undef,undef,$table); };
       return $self->_error('failed call to primary_key_info') unless $sth;
-
+      
       my %map = ();
       while (my $row = $sth->fetchrow_hashref()) {
             next unless $row->{PK_NAME} eq 'PRIMARY KEY';
